@@ -11,7 +11,7 @@ CHANNELS = [
 ]
 NICK = 'helgabot-dev'
 
-ENABLED_PLUGINS = ['stfu', 'help', 'oneliner', 'manager', 'updates']
+ENABLED_PLUGINS = ['stfu', 'help', 'oneliner', 'manager', 'reminders', 'crickets', 'haskell', 'flip']
 
 WEBHOOKS_CREDENTIALS = []
 
@@ -27,3 +27,5 @@ FES_CONFLUENCE_EDIT_URL = 'http://intranet.cmgdigital.com/pages/editpage.action?
 
 JIRA_AUTH = ('sduncan', 'One19@3#2')
 JIRA_REST_API = 'https://jira.cmgdigital.com/rest/api/latest/issue/{ticket}'
+
+CRICKETS_TIMEOUT = 5
